define(['dom', 'underscore', 'sandbox', 'marionette', 'text!../templates/alert.html'],
  function($, _, sandbox, Marionette, template) {


  var alert, error, warning, success, info;

  alert = Marionette.ItemView.extend({

    defaults: {
      hide_close_button: false
    },

    content: '',

    classes: ['alert'],

    template: template,

    /**
     * @param {Object} options k/v object, can contain `{string}content` with an error message
     *                         and `{array}classes` with extra CSS classes to add to the alert div
     */
    initialize: function(options) {
      options = options || {};

      this.content = options.content || '';
      delete options.content;

      this.classes = this.classes.concat(options.classes || []);
      delete options.classes;

      this.defaults = _.extend(this.defaults, options);
    },

    onRender: function() {
      // proxy any Bootstrap generated events to the Backbone view, to make sure all event
      // handlers, etc, are cleaned up, regardless of how the view is closed
      this.$el.alert()
        .bind('closed', $.proxy(this.close, this))
        .bind('close', $.proxy(this.trigger, this, 'before_close'));

      this.$el.addClass(this.classes.join(' '));
    },

    onClose: function() {
      // remove any Bootstrap events when we close the Backbone view
      this.$el.unbind();
    },

    serializeData: function() {

      var data = {
        classes: this.classes.join(' '),
        content: this.content
      }

      return _.extend(data, this.defaults);
    }

  });

  var Alerts = {
    alert: alert
  };

  // generate alert views for each Bootstrap type
  _.each(['error', 'warning', 'success', 'info'], function(type) {

      Alerts[type] = alert.extend({
        initialize: function(options) {
          alert.prototype.initialize.call(this, options);
          this.classes.push('alert-' + type);
        }
      });

  });

  return Alerts;
});