define(['core_models/user'], function(UserModel) {

  describe('The logged in user', function() {
    var user;

    beforeEach(function() {
      user = new UserModel();
    });

    it('should default to being read-only', function() {
      expect(user.get('role')).toBe('read-only');
    });

    it('should not be considered read-write if their role is read-only', function() {
      expect(user.read_write()).toBeFalsy();
    });

    it('should not be considered admin if their role is read-only', function() {
      expect(user.admin()).toBeFalsy();
    });

    it('should be considered read-write if their role is read-write', function() {
      user.set('role', 'read-write');

      expect(user.read_write()).toBeTruthy();
    });

    it('should not be considered an admin if their role is read-write', function() {
      user.set('role', 'read-write');

      expect(user.admin()).toBeFalsy();
    });

    it('should be considered read-write if they are an admin', function() {
      user.set('role', 'admin');

      expect(user.read_write()).toBeTruthy();
    });

    it('should be considered admin if they are an admin', function() {
      user.set('role', 'admin');

      expect(user.admin()).toBeTruthy();
    });
  });

});